@@ -22,10 +22,6 @@ local({
     # resolve bookdown references (figures, tables, sections, ...)
     bookdown:::process_markdown(out2, 'markdown', NULL, TRUE, to_md)
     # protect math expressions in backticks
-    if (xfun::loadable('xaringan')) {
-      blogdown:::process_file(out2, xaringan:::protect_math)
-    } else {
-      warning('The xaringan package is not installed. LaTeX math may not work well.')
-    }
+    blogdown:::process_file(out2, xfun::protect_math)
   }
 })
